# edwh-whitelabel-plugin

[![PyPI - Version](https://img.shields.io/pypi/v/edwh-whitelabel-plugin.svg)](https://pypi.org/project/edwh-whitelabel-plugin)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/edwh-whitelabel-plugin.svg)](https://pypi.org/project/edwh-whitelabel-plugin)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install edwh-whitelabel-plugin
```

But probably you want to install the whole edwh package:

```console
pipx install edwh[whitelabel]
# or
pipx install edwh[plugins,omgeving]
```

## License

`edwh-whitelabel-plugin` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
